powered by
The population parameters for Bull Trout in Adams Lake from Bison et al (2003)
adams_bt_03
An object of class ypr_population().
ypr_population()
Bison, R., O<U+2019>Brien, D., and Martell, S.J.D. 2003. An Analysis of Sustainable Fishing Options for Adams Lake Bull Trout Using Life History and Telemetry Data. BC Ministry of Water Land and Air Protection, Kamloops, B.C.
# NOT RUN { adams_bt_03 ypr_plot_yield(adams_bt_03) # }
Run the code above in your browser using DataLab